Index: src/uk/me/parabola/imgfmt/app/dem/DEMFile.java
===================================================================
--- src/uk/me/parabola/imgfmt/app/dem/DEMFile.java	(revision 4068)
+++ src/uk/me/parabola/imgfmt/app/dem/DEMFile.java	(working copy)
@@ -22,6 +22,7 @@
 import uk.me.parabola.imgfmt.app.ImgFileWriter;
 import uk.me.parabola.imgfmt.fs.ImgChannel;
 import uk.me.parabola.mkgmap.reader.hgt.HGTConverter;
+import uk.me.parabola.imgfmt.Utils;
 
 /**
  * The DEM file. This consists of information about elevation. It is used for hill shading
@@ -52,11 +53,29 @@
 	 * @param outsidePolygonHeight the height value that should be used for points outside of the bounding polygon 
 	 */
 	public void calc(Area area, java.awt.geom.Area demPolygonMapUnits, String pathToHGT, List<Integer> pointDistances, short outsidePolygonHeight) {
-		HGTConverter hgtConverter = new HGTConverter(pathToHGT, area, demPolygonMapUnits);
+		// expand HGT area for aligning with resolution 1200 (3'')
+		Area hgtArea = calcHGTArea(area, 1200);
+
+		HGTConverter hgtConverter = new HGTConverter(pathToHGT, hgtArea, demPolygonMapUnits);
 		hgtConverter.setOutsidePolygonHeight(outsidePolygonHeight);
 
+		int res = hgtConverter.getHighestRes();
+		if (res >= 1200) {
+			if (pointDistances.get(0) == -1 || pointDistances.get(0) == (int) ((1 << 29) / (res * 45))) {
+				// align area with HGT raster
+				if (res == 1200) {
+					// already calculated
+					area = hgtArea;
+				}
+				else {
+					area = calcHGTArea(area, res);
+				}
+				System.out.println("DEM aligned to HGT, resolution " + res);
+			}
+		}
+
 		int zoom = 0;
-		int lastDist = pointDistances.get(pointDistances.size()-1); 
+		int lastDist = pointDistances.get(pointDistances.size() - 1); 
 		for (int pointDist : pointDistances) {
 			DEMSection section = new DEMSection(zoom++, area, hgtConverter, pointDist, pointDist == lastDist);
 			demHeader.addSection(section);
@@ -64,8 +83,28 @@
 		return;
 	}
 
-	
-	
+	/**
+	 * Calculate area for given bounding box that is aligned to HGT raster with given resolution,
+	 * the box is moved left and up to achieve that.
+	 * @param bbox the bounding box
+	 * @param res the resolution
+	 * @return the new, eventually moved area
+	 */
+	private static Area calcHGTArea(Area bbox, int res) {
+		double top = Utils.toDegrees(bbox.getMaxLat());
+		double bottom = Utils.toDegrees(bbox.getMinLat());
+		double left = Utils.toDegrees(bbox.getMinLong());
+		double right = Utils.toDegrees(bbox.getMaxLong());
+
+		// expand HGT area for aligning with resolution 1200
+		double hgtDis = 1.0D / res;
+		double hgtTop = Math.ceil(top / hgtDis) * hgtDis;
+		double hgtBottom = bottom + hgtTop - top; 
+		double hgtLeft = Math.floor(left / hgtDis) * hgtDis;
+		double hgtRight = right  + hgtLeft - left; 
+		return new Area(hgtBottom, hgtLeft, hgtTop, hgtRight);
+	}
+
 	public void write() {
 		ImgFileWriter w = getWriter();
 		if (w instanceof BufferedImgFileWriter) {
Index: src/uk/me/parabola/mkgmap/reader/hgt/HGTConverter.java
===================================================================
--- src/uk/me/parabola/mkgmap/reader/hgt/HGTConverter.java	(revision 4068)
+++ src/uk/me/parabola/mkgmap/reader/hgt/HGTConverter.java	(working copy)
@@ -91,6 +91,9 @@
 		int row = (int) ((lat32 - minLat32) * FACTOR);
 		int col = (int) ((lon32 - minLon32) * FACTOR);
 
+		if (row < 0 || col < 0 || row >= readers.length || col >= readers[row].length ) {
+			log.error("requested value not in inital bbox", lat32, lon32);
+		}
 		HGTReader rdr = readers[row][col];
 		if (rdr == null) {
 			// no reader : ocean or missing file
